// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/cards/portfolio_card/widgets/portfolio_card_titles.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';

const _avatarAndTitlesSpacing = 25.0;

class PortfolioCardHeader extends StatelessWidget {
  const PortfolioCardHeader({
    this.logo,
    this.projectName,
    this.subtitle,
    this.keywords,
    this.keywordsBackgroundColors,
    this.titleStyle,
    this.subtitleStyle,
    this.keywordsStyle,
    super.key,
  });

  /// The logo of the portfolio card.
  final Widget? logo;

  /// Project name of the portfolio card.
  final TextWrapper? projectName;

  /// Subtitle of the portfolio card.
  final TextWrapper? subtitle;

  /// The keywords of the portfolio card.
  final List<TextWrapper>? keywords;

  /// Background colors for the keywords badges
  final MultiColor? keywordsBackgroundColors;

  /// Styles the title of the card.
  final TextStyle? titleStyle;

  /// Styles the subtitle of the card.
  final TextStyle? subtitleStyle;

  /// Styles the keywords of the card.
  final TextStyle? keywordsStyle;

  @override
  Widget build(BuildContext context) => Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Row(
            children: [
              if (logo != null) logo!,
              const Gap(_avatarAndTitlesSpacing),
              Expanded(
                child: PortfolioCardTitles(
                  axis: Axis.horizontal,
                  title: projectName,
                  subtitle: subtitle,
                  titleStyle: titleStyle,
                  subtitleStyle: subtitleStyle,
                ),
              ),
            ],
          ),
          const Gap(10),
          Wrap(
            children: [
              if (keywords != null)
                ...keywords!.map(
                  (word) => Container(
                    margin: const EdgeInsets.all(3),
                    padding: const EdgeInsets.all(6),
                    decoration: BoxDecoration(
                      gradient:
                          ThemeHelper.maybeGetElement<MultiColor, Gradient>(
                        [
                          keywordsBackgroundColors,
                        ],
                        valueValidator: (multiColor) => multiColor?.isGradient,
                        transform: (multiColor) =>
                            GradientHelper.linearFromMultiColor(multiColor!),
                      ),
                      color: ThemeHelper.maybeGetElement<MultiColor, Color>(
                        [
                          keywordsBackgroundColors,
                          Theme.of(context)
                              .extension<CardThemeExtension>()
                              ?.borderColors,
                          MultiColor.single(
                            Theme.of(context).cardTheme.surfaceTintColor,
                          ),
                          CardThemeExtensionDefault.from(Theme.of(context))
                              .borderColors,
                        ],
                        valueValidator: (multiColor) =>
                            multiColor != null && multiColor.isColor,
                        transform: (multiColor) => multiColor?.color,
                      ),
                      borderRadius: BorderRadius.circular(8),
                    ),
                    child: GradientText.fromWrapper(
                      word,
                      style: context.textTheme.bodySmall,
                    ),
                  ),
                ),
            ],
          ),
        ],
      );
}
