// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';

class PortfolioCardImages extends StatelessWidget {
  const PortfolioCardImages({
    this.assets,
    this.radius,
    this.maxSize,
    super.key,
  });

  /// The assets to display.
  final List<Widget>? assets;

  /// The radius of the assets.
  final BorderRadiusGeometry? radius;

  /// The max size of the assets.
  final Size? maxSize;

  @override
  Widget build(BuildContext context) {
    final result = <Widget>[];
    for (final asset in assets ?? List<Widget>.empty()) {
      result.addAll([
        Expanded(
          child: ClipRRect(
            borderRadius: radius ?? BorderRadius.zero,
            child: Container(
              constraints: BoxConstraints(
                maxHeight: maxSize != null ? maxSize!.width : double.infinity,
              ),
              child: asset,
            ),
          ),
        ),
        const Gap(25),
      ]);
    }
    result.removeLast();
    return Row(
      mainAxisAlignment: MainAxisAlignment.center,
      children: result,
    );
  }
}
